@@ -1,6 +1,7 @@
-__version__ = "0.7.2"
+__version__ = "0.8.0"
 
 import os
+
 from .bootstrap import _logging, setup_terrier, setup_jnius, is_windows
 
 import importlib
@@ -21,6 +22,7 @@ pipelines = None
 rewrite = None
 text = None
 transformer = None
+Transformer = None
 
 file_path = os.path.dirname(os.path.abspath(__file__))
 firstInit = False
@@ -78,8 +80,7 @@ def init(version=None, mem=None, packages=[], jvm_opts=[], redirect_io=True, log
     import platform
     from packaging.version import Version
     if Version(platform.python_version()) < Version('3.7.0'):
-        from warnings import warn
-        warn("From PyTerrier 0.8, Python 3.7 will be required, you currently have %s" % platform.python_version())
+        raise RuntimeError("From PyTerrier 0.8, Python 3.7 minimum is required, you currently have %s" % platform.python_version())
 
     set_tqdm(tqdm)
 
@@ -131,7 +132,8 @@ def init(version=None, mem=None, packages=[], jvm_opts=[], redirect_io=True, log
     version_string = tr_version.VERSION
     if "BUILD_DATE" in dir(tr_version):
         version_string += " (built by %s on %s)" % (tr_version.BUILD_USER, tr_version.BUILD_DATE)
-    print("PyTerrier %s has loaded Terrier %s" % (__version__, version_string))
+    import sys
+    print("PyTerrier %s has loaded Terrier %s\n" % (__version__, version_string), file=sys.stderr)
     properties = autoclass('java.util.Properties')()
     ApplicationSetup = autoclass('org.terrier.utility.ApplicationSetup')
 
@@ -140,6 +142,7 @@ def init(version=None, mem=None, packages=[], jvm_opts=[], redirect_io=True, log
     from .datasets import get_dataset, find_datasets, list_datasets
     from .index import Indexer, FilesIndexer, TRECCollectionIndexer, DFIndexer, DFIndexUtils, IterDictIndexer, FlatJSONDocumentIterator, IndexingType
     from .pipelines import Experiment, GridScan, GridSearch, KFoldGridSearch
+    from .transformer import Transformer
 
     # Make imports global
     globals()["autoclass"] = autoclass
@@ -175,7 +178,7 @@ def init(version=None, mem=None, packages=[], jvm_opts=[], redirect_io=True, log
     globals()["find_datasets"] = find_datasets
     globals()["Experiment"] = Experiment
     globals()["BatchRetrieve"] = BatchRetrieve
-    globals()["TerrierRetrieve"] = BatchRetrieve # TerrierRetrieve is an alias to BatchRetrieve
+    globals()["TerrierRetrieve"] = BatchRetrieve  # TerrierRetrieve is an alias to BatchRetrieve
     globals()["Indexer"] = Indexer
     globals()["FeaturesBatchRetrieve"] = FeaturesBatchRetrieve
     globals()["TRECCollectionIndexer"] = TRECCollectionIndexer
@@ -191,6 +194,7 @@ def init(version=None, mem=None, packages=[], jvm_opts=[], redirect_io=True, log
     globals()["GridScan"] = GridScan
     globals()["GridSearch"] = GridSearch
     globals()["KFoldGridSearch"] = KFoldGridSearch
+    globals()["Transformer"] = Transformer
     
     
     # we save the pt.init() arguments so that other processes,
