@@ -1,12 +1,10 @@
-from collections import defaultdict
 from warnings import warn
 import os
 import pandas as pd
 import numpy as np
 from typing import Callable, Union, Dict, List, Tuple, Sequence, Any
-from .utils import Utils
-from .transformer import TransformerBase, EstimatorBase
-from .model import add_ranks, coerce_dataframe_types
+from .transformer import TransformerBase
+from .model import coerce_dataframe_types
 import deprecation
 import ir_measures
 from ir_measures.measures import BaseMeasure 
@@ -335,6 +333,9 @@ def Experiment(
     if warn_old_sig:
         warn("Signature of Experiment() is now (retr_systems, topics, qrels, eval_metrics), please update your code", DeprecationWarning, 2)
 
+    if not isinstance(retr_systems, list):
+        raise TypeError("Expected list of transformers for retr_systems, instead received %s" % str(type(retr_systems)))
+
     if 'drop_unused' in kwargs:
         filter_by_qrels = kwargs.pop('drop_unused')
         warn('drop_unused is deprecated; use filter_by_qrels instead', DeprecationWarning)
@@ -346,9 +347,11 @@ def Experiment(
         assert not perquery
 
     if isinstance(topics, str):
+        from . import Utils
         if os.path.isfile(topics):
             topics = Utils.parse_trec_topics_file(topics)
     if isinstance(qrels, str):
+        from . import Utils
         if os.path.isfile(qrels):
             qrels = Utils.parse_qrels(qrels)
 
@@ -432,8 +435,10 @@ def Experiment(
         'desc' : 'pt.Experiment'
     }
     if batch_size is not None:
+        import math
         tqdm_args['unit'] = 'batches'
-        tqdm_args['total'] = (len(topics) / batch_size) * len(retr_systems)
+        # round number of batches up for each system
+        tqdm_args['total'] = math.ceil((len(topics) / batch_size)) * len(retr_systems)
 
     with tqdm(**tqdm_args) as pbar:
         # run and evaluate each system
@@ -453,6 +458,7 @@ def Experiment(
 
             if baseline is not None:
                 evalDictsPerQ.append(evalMeasuresDict)
+                from . import Utils
                 evalMeasuresDict = Utils.mean_of_measures(evalMeasuresDict)
 
             if perquery:
@@ -818,7 +824,7 @@ def GridScan(
     for tran, param in candi_dict:
         try:
             tran.get_parameter(param)
-        except Exception as e:
+        except:
             raise ValueError("Transformer %s does not expose a parameter named %s" % (str(tran), param))
     
     keys,values = zip(*candi_dict.items())
