@@ -6,7 +6,7 @@ import pandas as pd
 from .model import add_ranks
 from . import tqdm
 import deprecation
-from typing import Iterable, Iterator
+from typing import Iterable, Iterator, Union
 
 LAMBDA = lambda:0
 def is_lambda(v):
@@ -31,10 +31,13 @@ def get_transformer(v):
     if is_transformer(v):
         return v
     if is_lambda(v):
+        warn('Coercion of a lambda into a transformer is deprecated; use a pt.apply instead')
         return ApplyGenericTransformer(v)
     if is_function(v):
+        warn('Coercion of a function into a transformer is deprecated; use a pt.apply instead')
         return ApplyGenericTransformer(v)
     if isinstance(v, pd.DataFrame):
+        warn('Coercion of a dataframe into a transformer is deprecated; use a pt.Transformer.from_df() instead')
         return SourceTransformer(v)
     raise ValueError("Passed parameter %s of type %s cannot be coerced into a transformer" % (str(v), type(v)))
 
@@ -111,14 +114,29 @@ class Scalar(Symbol):
         super().__init__(name)
         self.value = value
 
-class TransformerBase:
-    name = "TransformerBase"
+class Transformer:
+    name = "Transformer"
     """
         Base class for all transformers. Implements the various operators ``>>`` ``+`` ``*`` ``|`` ``&`` 
         as well as ``search()`` for executing a single query and ``compile()`` for rewriting complex pipelines into more simples ones.
     """
 
-    def transform(self, topics_or_res):
+    @staticmethod
+    def from_df(input : pd.DataFrame, uniform=False) -> 'Transformer':
+        """
+        Instantiates a transformer from an input dataframe. Some rows from the input dataframe are returned
+        in response to a query on the ``transform()`` method. Depending on the value `uniform`, the dataframe
+        passed as an argument to ``transform()`` can affect this selection.
+
+        If `uniform` is True, input will be returned in its entirety each time.
+        If `uniform` is False, rows from input that match the qid values from the argument dataframe.
+        
+        """
+        if uniform:
+            return UniformTransformer(input)
+        return SourceTransformer(input)
+
+    def transform(self, topics_or_res : pd.DataFrame) -> pd.DataFrame:
         """
             Abstract method for all transformations. Typically takes as input a Pandas
             DataFrame, and also returns one.
@@ -200,7 +218,7 @@ class TransformerBase:
             rtr = rtr.sort_values(["qid", "rank"], ascending=[True,True])
         return rtr
 
-    def compile(self):
+    def compile(self) -> 'Transformer':
         """
         Rewrites this pipeline by applying of the Matchpy rules in rewrite_rules. Pipeline
         optimisation is discussed in the `ICTIR 2020 paper on PyTerrier <https://arxiv.org/abs/2007.14271>`_.
@@ -210,7 +228,7 @@ class TransformerBase:
         print("Applying %d rules" % len(rewrite_rules))
         return replace_all(self, rewrite_rules)
 
-    def parallel(self, N : int, backend='joblib'):
+    def parallel(self, N : int, backend='joblib') -> 'Transformer':
         """
         Returns a parallelised version of this transformer. The underlying transformer must be "picklable".
 
@@ -244,52 +262,57 @@ class TransformerBase:
             raise ValueError(('Invalid parameter name %s for transformer %s. '+
                     'Check the list of available parameters') %(name, str(self)))
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs) -> pd.DataFrame:
         """
             Sets up a default method for every transformer, which is aliased to transform(). 
         """
         return self.transform(*args, **kwargs)
 
-    def __rshift__(self, right):
+    def __rshift__(self, right) -> 'Transformer':
         return ComposedPipeline(self, right)
 
-    def __rrshift__(self, left):
+    def __rrshift__(self, left) -> 'Transformer':
         return ComposedPipeline(left, self)
 
-    def __add__(self, right):
+    def __add__(self, right : 'Transformer') -> 'Transformer':
         return CombSumTransformer(self, right)
 
-    def __pow__(self, right):
+    def __pow__(self, right : 'Transformer') -> 'Transformer':
         return FeatureUnionPipeline(self, right)
 
-    def __mul__(self, rhs):
+    def __mul__(self, rhs : Union[float,int]) -> 'Transformer':
         assert isinstance(rhs, int) or isinstance(rhs, float)
         return ScalarProductTransformer(self, rhs)
 
-    def __rmul__(self, lhs):
+    def __rmul__(self, lhs : Union[float,int]) -> 'Transformer':
         assert isinstance(lhs, int) or isinstance(lhs, float)
         return ScalarProductTransformer(self, lhs)
 
-    def __or__(self, right):
+    def __or__(self, right : 'Transformer') -> 'Transformer':
         return SetUnionTransformer(self, right)
 
-    def __and__(self, right):
+    def __and__(self, right : 'Transformer') -> 'Transformer':
         return SetIntersectionTransformer(self, right)
 
-    def __mod__(self, right):
+    def __mod__(self, right : 'Transformer') -> 'Transformer':
         assert isinstance(right, int)
         return RankCutoffTransformer(self, right)
 
-    def __xor__(self, right):
+    def __xor__(self, right : 'Transformer') -> 'Transformer':
         return ConcatenateTransformer(self, right)
 
-    def __invert__(self):
+    def __invert__(self : 'Transformer') -> 'Transformer':
         from .cache import ChestCacheTransformer
         return ChestCacheTransformer(self)
 
     def __hash__(self):
         return hash(repr(self))
 
+class TransformerBase(Transformer):
+    # this was the older name of Transformer.
+    # it will be deprecated in a future release.
+    pass
+
 class IterDictIndexerBase(TransformerBase):
     def index(self, iter : Iterable[dict], **kwargs):
         """
@@ -733,14 +756,16 @@ class FeatureUnionPipeline(NAryTransformerBase):
 
     def transform(self, inputRes):
         if not "docno" in inputRes.columns and "docid" in inputRes.columns:
-            raise ValueError("FeatureUnion operates as a re-ranker, but input did not have either docno or docid columns, found columns were %s" %  str(inputRes.columns))
+            raise ValueError("FeatureUnion operates as a re-ranker, but input did not have either "
+                "docno or docid columns, found columns were %s" %  str(inputRes.columns))
 
         num_results = len(inputRes)
         import numpy as np
 
         # a parent could be a feature union, but it still passes the inputRes directly, so inputRes should never have a features column
         if "features" in inputRes.columns:
-            raise ValueError("FeatureUnion operates as a re-ranker. They can be nested, but input should not contain a features column; found columns were %s" %  str(inputRes.columns))
+            raise ValueError("FeatureUnion operates as a re-ranker. They can be nested, but input "
+                "should not contain a features column; found columns were %s" %  str(inputRes.columns))
         
         all_results = []
 
@@ -761,7 +786,8 @@ class FeatureUnionPipeline(NAryTransformerBase):
                     raise ValueError("Results from %s did not include either score or features columns, found columns were %s" % (repr(m), str(res.columns)) )
 
                 if len(res) != num_results:
-                    warn("Got number of results different expected from %s, expected %d received %d, feature scores for any missing documents be 0, extraneous documents will be removed" % (repr(m), num_results, len(res)))
+                    warn("Got number of results different expected from %s, expected %d received %d, feature scores for any "
+                        "missing documents be 0, extraneous documents will be removed" % (repr(m), num_results, len(res)))
                     all_results[i] = res = inputRes[["qid", "docno"]].merge(res, on=["qid", "docno"], how="left")
                     res["score"] = res["score"].fillna(value=0)
 
